import { Component } from '@angular/core';
import * as Diagramming from '@mindfusion/diagramming';
import * as Drawing from '@mindfusion/drawing';
import * as Graphs from '@mindfusion/graphs';

@Component({
  selector: 'inheritance',
  templateUrl: './inheritance.html'
})
export class Inheritance {

  diagram: Diagramming.Diagram;

  constructor() {

    Diagramming.TableNode.prototype.useScrollBars = true;

    this.diagram = new Diagramming.Diagram();
    this.diagram.theme = Diagramming.Theme.getBusiness();

    this.createClassDiagram(this.diagram,
      [
        Diagramming.DiagramItem,
        Diagramming.DiagramLink,
        Diagramming.DiagramNode,
        Diagramming.ShapeNode,
        Diagramming.TableNode,
        Diagramming.ContainerNode,
        Diagramming.FreeFormNode,
        Diagramming.SvgNode
      ]);
  }

  createClassDiagram(diagram: Diagramming.Diagram, classes: any) {

    // create a table node for each class
    for (let i = 0; i < classes.length; i++) {
      let theClass = classes[i];
      let node = diagram.factory.createTableNode(20, 20, 42, 42);
      node.redimTable(1, 0);
      node.text = (theClass.name);
      node.brush = ("white");
      node.captionBackBrush = ("#c0c0c0");
      node.captionFont = (
        new Drawing.Font("sans-serif", 3, true /*bold*/, true /*italic*/));
      node.scrollable = (true);

      Object.getOwnPropertyNames(theClass.prototype).forEach(function (property) {
        node.addRow();
        let cell = node.getCell(0, node.rows.length - 1);
        cell.text = property.toString();
      });

      theClass.classNode = node;

      // add links
      let baseNode = Object.getPrototypeOf(theClass).classNode;
      if (baseNode) {
        let link = diagram.factory.createDiagramLink(
          baseNode,
          theClass.classNode);
        //	link.headShape = null;
        link.baseShape = "Triangle";
        link.baseShapeSize = 3;
      }
    }

    // arrange as a tree
    let treeLayout = new Graphs.TreeLayout();
    treeLayout.linkType = Graphs.TreeLayoutLinkType.Cascading;
    diagram.arrange(treeLayout);
  }

  getBaseType(ctor: any) {
    // if class registered using MindFusion.registerClass
    if (ctor.__baseType)
      return ctor.__baseType;

    // if  prototypical inheritance with Child.prototype = new Parent()
    if (ctor.prototype && ctor.prototype.constructor !== ctor)
      return ctor.prototype.constructor;

    return null;
  }

}