import React, { useState, useEffect } from 'react';
import Info from './Info';
import * as Drawing from '@mindfusion/drawing';
import * as Diagramming from '@mindfusion/diagramming';
import * as Graphs from '@mindfusion/graphs';
import { DiagramView } from '@mindfusion/diagramming-react';

const createClassDiagram = (diagram, classes) => {
  // create a table node for each class
  for (let i = 0; i < classes.length; i++) {
    let theClass = classes[i];
    let node = diagram.factory.createTableNode(20, 20, 42, 42);
    node.redimTable(1, 0);
    node.text = theClass.name;
    node.brush = "white";
    node.captionBackBrush = "#c0c0c0";
    node.captionFont = new Drawing.Font("sans-serif", 3, true /*bold*/, true /*italic*/);
    node.scrollable = true;

    Object.getOwnPropertyNames(theClass.prototype).forEach(function (property) {
      node.addRow();
      let cell = node.getCell(0, node.rows.length - 1);
      cell.text = property.toString();
    });

    theClass.classNode = node;

    // add links
    let baseNode = Object.getPrototypeOf(theClass).classNode;
    if (baseNode) {
      let link = diagram.factory.createDiagramLink(
        baseNode,
        theClass.classNode);
      link.headShape = null;
      link.baseShape = "Triangle";
      link.baseShapeSize = 3;
    }
  }

  // arrange as a tree
  let treeLayout = new Graphs.TreeLayout();
  treeLayout.linkType = Graphs.TreeLayoutLinkType.Cascading;
  diagram.arrange(treeLayout);
}

function Inheritance() {
  const [diagram] = useState(new Diagramming.Diagram());

  useEffect(() => {
  Diagramming.TableNode.prototype.useScrollBars = true;
  Diagramming.ScrollBar.prototype.background = "#e0e9e9";
  Diagramming.ScrollBar.prototype.foreground = "DarkGray";

  diagram.theme = Diagramming.Theme.getBusiness();

  createClassDiagram(diagram,
    [
      Diagramming.DiagramItem,
      Diagramming.DiagramLink,
      Diagramming.DiagramNode,
      Diagramming.ShapeNode,
      Diagramming.TableNode,
      Diagramming.ContainerNode,
      Diagramming.FreeFormNode,
      Diagramming.SvgNode
    ]);
  }, [diagram]);

  return (
    <div className="App">
      <div className="header">
      </div>
      <div className="container">
        <div className="main">
          <DiagramView
            diagram={diagram} />
        </div>
        <div className="sidebar">
          <h1>About this sample</h1>
          <p>This sample page shows how to build a class inheritance diagram.
            Classes are represented by instances of the TableNode class. Each property of the class prototype is
            listed in a TableNode cell.
            Finally, the diagram is arranged using the TreeLayout algorithm.</p>
          <Info />
        </div>
      </div>

      <div className="footer">
        <p>Copyright 2024 MindFusion LLC.</p>
      </div>

    </div>
  );
}

export default Inheritance;
