import React, { useState, useRef } from 'react';
import Info from './Info';
import * as Diagramming from '@mindfusion/diagramming';
import * as DControls from '@mindfusion/diagramming-controls';
import { TabbedDiagramView, Overview } from '@mindfusion/diagramming-react';
import { Dialogs, ModalResult } from '@mindfusion/common-ui';

import black from "@mindfusion/common-ui/themes/black.css";
import blue from "@mindfusion/common-ui/themes/blue.css";
import standard from "@mindfusion/common-ui/themes/standard.css";
import gray from "@mindfusion/common-ui/themes/gray.css";
import light from "@mindfusion/common-ui/themes/light.css";
import peach from "@mindfusion/common-ui/themes/peach.css";
import pastel from "@mindfusion/common-ui/themes/pastel.css";
import business from "@mindfusion/common-ui/themes/business.css";
import earth from "@mindfusion/common-ui/themes/earth.css";
import green from "@mindfusion/common-ui/themes/green.css";


function TabbedView() {
  const [tabAlignment, setTabAlignment] = useState(DControls.TabAlignment.Top);
  const [showNavigationButtons, setShowNavigationButtons] = useState(true);
  const [showAddButton, setShowAddButton] = useState(true);
  const [showTabCloseButtons, setShowTabCloseButtons] = useState(false);
  const [diagramView, setDiagramView] = useState(null);
  const diagramViewElement = useRef(null);

  const onControlLoaded = () =>
  {
    setDiagramView(diagramViewElement.current);
  }

  const onPageRemoving = (sender : DControls.TabbedDiagramView, args : DControls.PageEventArgs) => {
    if (args.oldPage.items.length == 0) return;
    args.cancel = true;
    Dialogs.showConfirmDialog("Confirm", "Unsaved changes, close anyway?", (result : ModalResult) => {
      if (result == ModalResult.OK) sender.document.removePage(args.oldPage);
    }, document.querySelector(".main") as HTMLDivElement, 
    (document.getElementById("theme") as HTMLSelectElement).value);
  }



  const onAlignmentChange = (e : React.ChangeEvent<HTMLSelectElement>) => {
    setTabAlignment(+e.target.value);
  }

  const onShowNavChange = (e: React.ChangeEvent<HTMLInputElement>) => {
    setShowNavigationButtons(e.target.checked);
  }

  const onShowAddChange = (e: React.ChangeEvent<HTMLInputElement>) => {
    setShowAddButton(e.target.checked);
  }

  const onShowCloseChange = (e: React.ChangeEvent<HTMLInputElement>) => {
    setShowTabCloseButtons(e.target.checked);
  }

  const onThemeChange = (e: React.ChangeEvent<HTMLSelectElement>) => {
    var t = Diagramming.Theme.fromId(e.target.value);
    (diagramViewElement.current! as any).find().setTheme(t, true);
  }

  var props = {
    "id": "diagram",
    "tabAlignment": tabAlignment,
    "showNavigationButtons": showNavigationButtons,
    "showAddButton": showAddButton,
    "showTabCloseButtons": showTabCloseButtons
  };

  return (
    <div className="App">
      <div className="header">
        TabAlignment
        <select id="tabAlignment" onChange={onAlignmentChange} defaultValue={1}>
          <option value="0">None</option>
          <option value="1">Top</option>
          <option value="3">Bottom</option>
        </select>
        <input id="showNavBtn" type="checkbox" defaultChecked onChange={onShowNavChange} /> Show navigation buttons
        <input id="showAddBtn" type="checkbox" defaultChecked onChange={onShowAddChange} /> Show 'Add Tab' button
        <input id="showCloseBtn" type="checkbox" onChange={onShowCloseChange} /> Show tabs close buttons
        Theme
        <select id="theme" onChange={onThemeChange}>
          <option value="">none</option>
          <option value="standard">standard</option>
          <option value="light">light</option>
          <option value="business">business</option>
          <option value="green">green</option>
          <option value="blue">blue</option>
          <option value="gray">gray</option>
          <option value="peach">peach</option>
          <option value="earth">earth</option>
          <option value="pastel">pastel</option>
          <option value="black">black</option>
        </select>


      </div>

      <div className="container">
        <div className="main">
          <div className="sidebar-left">
            <Overview diagramView={diagramView}></Overview>
          </div>
          <div className="main">
            <TabbedDiagramView
              {...props}
              style={{ position: "absolute", width: 'auto', height: 'auto', left: 0, right: 0, top: 0, bottom: 0 }}
              onControlLoaded={() => onControlLoaded()}
              onPageRemoving={(sender: DControls.TabbedDiagramView, args : DControls.PageEventArgs) => onPageRemoving(sender, args)}
              ref={diagramViewElement} />
          </div>
        </div>
        <div className="sidebar">
          <h1>About this sample</h1>
          <p>This sample shows the functionality of the TabbedDiagramView control.</p>
          <Info />
        </div>
      </div>

      <div className="footer">
        <p>Copyright 2024 MindFusion LLC.</p>
      </div>

    </div>
  );
}

export default TabbedView;
export { blue, business, earth, gray, green, light, pastel, peach, standard, black };